==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'PŘIDAT DOKUMENT',
	'bouton_ajouter_image' => 'PŘIDAT OBRÁZEK',
	'bouton_ajouter_image_document' => 'Přidat obrázek nebo dokument',

	// D
	'double_clic_inserer_doc' => 'Tuto zkratku vložíte do textu poklepáním',

	// E
	'entree_dimensions' => 'Velikost:',
	'entree_titre_document' => 'Název dokumentu:',
	'entree_titre_image' => 'Název obrázku:',

	// I
	'image_tourner_180' => 'Otočit o 180°',
	'image_tourner_droite' => 'Otočit o 90° doprava',
	'image_tourner_gauche' => 'Otočit o 90° doleva',
	'info_document' => 'Dokument',
	'info_documents' => 'Dokumenty',
	'info_inclusion_directe' => 'Přímé vložení:',
	'info_inclusion_vignette' => 'Vložit náhled:',
	'info_installer_tous_documents' => 'Instalovat všechny dokumenty',
	'info_logo_max_taille' => 'Logo nesmí být větší než @maxi@ (tento soubor má velikost @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Odkaz na dokument na internetu:',
	'info_telecharger' => 'Odeslat z počítače:',

	// T
	'texte_documents_joints' => 'Můžete povolit přidávání dokumentů (textových a jiných souborů, obrázků, multimédii atd.),
 a to jak k článkům tak i k sekcím. Na tyto soubory pak můžete v článcích
 odkazovat, případně je můžete zobrazovat samostatně.', # MODIF
	'texte_documents_joints_2' => 'I při tomto nastavení můžete vkládat obrázky přímo do článků.', # MODIF
	'titre_documents_joints' => 'Připojené dokumenty',
	'tout_dossier_upload' => 'Celá složka @upload@',

	// U
	'upload_fichier_zip' => 'Komprimovaný soubor ZIP',
	'upload_fichier_zip_texte' => 'Chcete nainstalovat komprimovaný soubor ZIP.',
	'upload_fichier_zip_texte2' => 'Tento soubor může být:',
	'upload_limit' => 'Soubor je pro server příliš velký. Maximální povolená velikost pro <i>odeslání</i> je @max@.',
	'upload_zip_decompacter' => 'rozbalený a každý ze souborů v něm obsažený bude na web nainstalován. Budou nainstalovány tyto soubory:',
	'upload_zip_telquel' => 'nainstalovat tak, jak je, tedy ve formátu ZIP;'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=cs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'PŘIDAT DOKUMENT',
	'bouton_ajouter_image' => 'PŘIDAT OBRÁZEK',
	'bouton_ajouter_image_document' => 'Přidat obrázek nebo dokument',

	// D
	'double_clic_inserer_doc' => 'Tuto zkratku vložíte do textu poklepáním',

	// E
	'entree_dimensions' => 'Velikost:',
	'entree_titre_document' => 'Název dokumentu:',
	'entree_titre_image' => 'Název obrázku:',

	// I
	'image_tourner_180' => 'Otočit o 180°',
	'image_tourner_droite' => 'Otočit o 90° doprava',
	'image_tourner_gauche' => 'Otočit o 90° doleva',
	'info_document' => 'Dokument',
	'info_documents' => 'Dokumenty',
	'info_inclusion_directe' => 'Přímé vložení:',
	'info_inclusion_vignette' => 'Vložit náhled:',
	'info_installer_tous_documents' => 'Instalovat všechny dokumenty',
	'info_logo_max_taille' => 'Logo nesmí být větší než @maxi@ (tento soubor má velikost @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Odkaz na dokument na internetu:',
	'info_telecharger' => 'Odeslat z počítače:',

	// T
	'texte_documents_joints' => 'Můžete povolit přidávání dokumentů (textových a jiných souborů, obrázků, multimédii atd.),
 a to jak k článkům tak i k sekcím. Na tyto soubory pak můžete v článcích
 odkazovat, případně je můžete zobrazovat samostatně.', # MODIF
	'texte_documents_joints_2' => 'I při tomto nastavení můžete vkládat obrázky přímo do článků.', # MODIF
	'titre_documents_joints' => 'Připojené dokumenty',
	'tout_dossier_upload' => 'Celá složka @upload@',

	// U
	'upload_fichier_zip' => 'Komprimovaný soubor ZIP',
	'upload_fichier_zip_texte' => 'Chcete nainstalovat komprimovaný soubor ZIP.',
	'upload_fichier_zip_texte2' => 'Tento soubor může být:',
	'upload_limit' => 'Soubor je pro server příliš velký. Maximální povolená velikost pro <i>odeslání</i> je @max@.',
	'upload_zip_decompacter' => 'rozbalený a každý ze souborů v něm obsažený bude na web nainstalován. Budou nainstalovány tyto soubory:',
	'upload_zip_telquel' => 'nainstalovat tak, jak je, tedy ve formátu ZIP;',
];
